@@ -74,7 +74,6 @@ import org.eclipse.che.api.workspace.server.spi.provision.env.JavaOptsEnvVariabl
 import org.eclipse.che.api.workspace.server.spi.provision.env.LegacyEnvVarProvider;
 import org.eclipse.che.api.workspace.server.spi.provision.env.MachineTokenEnvVarProvider;
 import org.eclipse.che.api.workspace.server.spi.provision.env.MavenOptsEnvVariableProvider;
-import org.eclipse.che.api.workspace.server.spi.provision.env.ProjectsRootEnvVariableProvider;
 import org.eclipse.che.api.workspace.server.spi.provision.env.WorkspaceIdEnvVarProvider;
 import org.eclipse.che.api.workspace.server.spi.provision.env.WorkspaceNameEnvVarProvider;
 import org.eclipse.che.api.workspace.server.spi.provision.env.WorkspaceNamespaceNameEnvVarProvider;
@@ -221,7 +220,6 @@ public class WsMasterModule extends AbstractModule {
     envVarProviders.addBinding().to(WorkspaceIdEnvVarProvider.class);
     envVarProviders.addBinding().to(WorkspaceNamespaceNameEnvVarProvider.class);
     envVarProviders.addBinding().to(WorkspaceNameEnvVarProvider.class);
-    envVarProviders.addBinding().to(ProjectsRootEnvVariableProvider.class);
 
     Multibinder<LegacyEnvVarProvider> legacyEnvVarProviderMultibinders =
         Multibinder.newSetBinder(binder(), LegacyEnvVarProvider.class);
