@@ -31,7 +31,6 @@ import io.fabric8.kubernetes.api.model.PodTemplateSpec;
 import io.fabric8.kubernetes.api.model.Secret;
 import io.fabric8.kubernetes.api.model.Service;
 import io.fabric8.kubernetes.api.model.apps.Deployment;
-import io.fabric8.kubernetes.api.model.networking.v1.Ingress;
 import io.opentracing.Scope;
 import io.opentracing.Span;
 import io.opentracing.Tracer;
@@ -47,10 +46,8 @@ import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.CompletionStage;
 import java.util.concurrent.CopyOnWriteArrayList;
-import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Executor;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 import java.util.function.Function;
@@ -114,7 +111,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
 
   private static final Logger LOG = LoggerFactory.getLogger(KubernetesInternalRuntime.class);
 
-  private final int workspaceStartTimeoutMin;
   private final long ingressStartTimeoutMillis;
   private final UnrecoverablePodEventListenerFactory unrecoverableEventListenerFactory;
   private final ServersCheckerFactory serverCheckerFactory;
@@ -139,7 +135,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
 
   @Inject
   public KubernetesInternalRuntime(
-      @Named("che.infra.kubernetes.workspace_start_timeout_min") int workspaceStartTimeoutMin,
       @Named("che.infra.kubernetes.ingress_start_timeout_min") int ingressStartTimeoutMin,
       NoOpURLRewriter urlRewriter,
       UnrecoverablePodEventListenerFactory unrecoverableEventListenerFactory,
@@ -166,7 +161,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     super(context, urlRewriter);
     this.unrecoverableEventListenerFactory = unrecoverableEventListenerFactory;
     this.serverCheckerFactory = serverCheckerFactory;
-    this.workspaceStartTimeoutMin = workspaceStartTimeoutMin;
     this.ingressStartTimeoutMillis = TimeUnit.MINUTES.toMillis(ingressStartTimeoutMin);
     this.probeScheduler = probeScheduler;
     this.probesFactory = probesFactory;
@@ -201,7 +195,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
 
       startSynchronizer.checkFailure();
 
-      startMachines();
       watchLogsIfDebugEnabled(startOptions);
 
       previewUrlCommandProvisioner.provision(context.getEnvironment(), namespace);
@@ -231,7 +224,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
                   .exceptionally(publishFailedStatus(startFailure, machineName));
           machinesFutures.put(machineName, machineBootChain);
         }
-        waitMachines(machinesFutures, toCancelFutures, startFailure);
       } finally {
         waitRunningAsyncSpan.finish();
       }
@@ -299,38 +291,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     LOG.debug("Provisioning of workspace '{}' completed.", workspaceId);
   }
 
-  /**
-   * Schedules runtime state checks that are needed after recovering of runtime.
-   *
-   * <p>Different checks will be scheduled according to current runtime status:
-   *
-   * <ul>
-   *   <li>STARTING - schedules servers checkers and starts tracking of starting runtime
-   *   <li>RUNNING - schedules servers checkers
-   *   <li>STOPPING - starts tracking of stopping runtime
-   *   <li>STOPPED - do nothing. Should not happen since only active runtimes are recovered
-   * </ul>
-   */
-  public void scheduleRuntimeStateChecks() throws InfrastructureException {
-    switch (getStatus()) {
-      case RUNNING:
-        scheduleServersCheckers();
-        break;
-
-      case STOPPING:
-        runtimeHangingDetector.trackStopping(this, workspaceStartTimeoutMin);
-        break;
-
-      case STARTING:
-        runtimeHangingDetector.trackStarting(this, workspaceStartTimeoutMin);
-        scheduleServersCheckers();
-        break;
-      case STOPPED:
-      default:
-        // do nothing
-    }
-  }
-
   /** Returns new function that wraps given with set/unset context logic */
   private <T, R> Function<T, R> setContext(EnvironmentContext context, Function<T, R> func) {
     return funcArgument -> {
@@ -343,63 +303,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     };
   }
 
-  /**
-   * Waits for readiness of given machines.
-   *
-   * @param machinesFutures machines futures to wait
-   * @param toCancelFutures futures that must be explicitly closed when any error occurs
-   * @param failure failure callback that is used to prevent subsequent steps when any error occurs
-   * @throws InfrastructureException when waiting for machines exceeds the timeout
-   * @throws InfrastructureException when any problem occurred while waiting
-   * @throws RuntimeStartInterruptedException when the thread is interrupted while waiting machines
-   */
-  private void waitMachines(
-      Map<String, CompletableFuture<Void>> machinesFutures,
-      List<CompletableFuture<?>> toCancelFutures,
-      CompletableFuture<Void> failure)
-      throws InfrastructureException {
-    try {
-      LOG.debug(
-          "Waiting to start machines of workspace '{}'",
-          getContext().getIdentity().getWorkspaceId());
-      final CompletableFuture<Void> allDone =
-          CompletableFuture.allOf(machinesFutures.values().toArray(new CompletableFuture[0]));
-
-      CompletableFuture.anyOf(allDone, failure)
-          .get(startSynchronizer.getStartTimeoutMillis(), TimeUnit.MILLISECONDS);
-
-      if (failure.isCompletedExceptionally()) {
-        cancelAll(toCancelFutures);
-        // rethrow the failure cause
-        failure.get();
-      }
-      LOG.debug("Machines of workspace '{}' started", getContext().getIdentity().getWorkspaceId());
-    } catch (TimeoutException ex) {
-      InfrastructureException ie =
-          new InfrastructureException(
-              "Waiting for Kubernetes environment '"
-                  + getContext().getIdentity().getEnvName()
-                  + "' of the workspace'"
-                  + getContext().getIdentity().getWorkspaceId()
-                  + "' reached timeout");
-      failure.completeExceptionally(ie);
-      cancelAll(toCancelFutures);
-      throw ie;
-    } catch (InterruptedException ex) {
-      RuntimeStartInterruptedException runtimeInterruptedEx =
-          new RuntimeStartInterruptedException(getContext().getIdentity());
-      failure.completeExceptionally(runtimeInterruptedEx);
-      cancelAll(toCancelFutures);
-      throw runtimeInterruptedEx;
-    } catch (ExecutionException ex) {
-      failure.completeExceptionally(ex.getCause());
-      cancelAll(toCancelFutures);
-      wrapAndRethrow(ex.getCause());
-      // note that we do NOT finish the startup traces here, because execution exception is
-      // handled by the "exceptional" parts of the completable chain.
-    }
-  }
-
   /**
    * Returns a function, the result of which the completable stage that performs servers checks and
    * start of servers probes.
@@ -568,30 +471,7 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
   @Override
   protected void internalStop(Map<String, String> stopOptions) throws InfrastructureException {
     RuntimeIdentity identity = getContext().getIdentity();
-
     TracingTags.WORKSPACE_ID.set(identity.getWorkspaceId());
-
-    runtimeHangingDetector.stopTracking(getContext().getIdentity());
-    if (startSynchronizer.interrupt()) {
-      // runtime is STARTING. Need to wait until start will be interrupted properly
-      try {
-        if (!startSynchronizer.awaitInterruption(workspaceStartTimeoutMin, TimeUnit.MINUTES)) {
-          // Runtime is not interrupted yet. It may occur when start was performing by another
-          // Che Server that is crashed so start is hung up in STOPPING phase.
-          // Need to clean up runtime resources
-          probeScheduler.cancel(identity.getWorkspaceId());
-          runtimeCleaner.cleanUp(namespace, identity.getWorkspaceId());
-        }
-      } catch (InterruptedException e) {
-        throw new InfrastructureException(
-            "Interrupted while waiting for start task cancellation", e);
-      }
-    } else {
-      // runtime is RUNNING. Clean up used resources
-      // Cancels workspace servers probes if any
-      probeScheduler.cancel(identity.getWorkspaceId());
-      runtimeCleaner.cleanUp(namespace, identity.getWorkspaceId());
-    }
   }
 
   @Override
@@ -599,30 +479,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     return emptyMap();
   }
 
-  /**
-   * Create all machine related objects and start machines.
-   *
-   * @throws InfrastructureException when any error occurs while creating Kubernetes objects
-   */
-  @Traced
-  protected void startMachines() throws InfrastructureException {
-    KubernetesEnvironment k8sEnv = getContext().getEnvironment();
-    String workspaceId = getContext().getIdentity().getWorkspaceId();
-
-    createSecrets(k8sEnv, workspaceId);
-    List<ConfigMap> createdConfigMaps = createConfigMaps(k8sEnv, getContext().getIdentity());
-    List<Service> createdServices = createServices(k8sEnv, workspaceId);
-
-    // needed for resolution later on, even though n routes are actually created by ingress
-    // /workspace{wsid}/server-{port} => service({wsid}):server-port => pod({wsid}):{port}
-    List<Ingress> readyIngresses = createIngresses(k8sEnv, workspaceId);
-
-    listenEvents();
-
-    doStartMachine(
-        serverResolverFactory.create(createdServices, readyIngresses, createdConfigMaps));
-  }
-
   @Traced
   protected void listenEvents() throws InfrastructureException {
     namespace
@@ -713,14 +569,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     return createdServices;
   }
 
-  @Traced
-  @SuppressWarnings("WeakerAccess") // package-private so that interception is possible
-  List<Ingress> createIngresses(KubernetesEnvironment env, String workspaceId)
-      throws InfrastructureException {
-    TracingTags.WORKSPACE_ID.set(workspaceId);
-    return createAndWaitReady(env.getIngresses().values());
-  }
-
   /**
    * Creates Kubernetes pods and resolves servers using the specified serverResolver.
    *
@@ -905,35 +753,6 @@ public class KubernetesInternalRuntime<E extends KubernetesEnvironment>
     runtimeStates.remove(getContext().getIdentity());
   }
 
-  private List<Ingress> createAndWaitReady(Collection<Ingress> ingresses)
-      throws InfrastructureException {
-    List<Ingress> createdIngresses = new ArrayList<>();
-    for (Ingress ingress : ingresses) {
-      createdIngresses.add(namespace.ingresses().create(ingress));
-    }
-    LOG.debug(
-        "Ingresses created for workspace '{}'. Wait them to be ready.",
-        getContext().getIdentity().getWorkspaceId());
-
-    // wait for LB ip
-    List<Ingress> readyIngresses = new ArrayList<>();
-    for (Ingress ingress : createdIngresses) {
-      Ingress actualIngress =
-          namespace
-              .ingresses()
-              .wait(
-                  ingress.getMetadata().getName(),
-                  // Smaller value of ingress and start timeout should be used
-                  Math.min(ingressStartTimeoutMillis, startSynchronizer.getStartTimeoutMillis()),
-                  TimeUnit.MILLISECONDS,
-                  p -> (!p.getStatus().getLoadBalancer().getIngress().isEmpty()));
-      readyIngresses.add(actualIngress);
-    }
-    LOG.debug(
-        "Ingresses creation for workspace '{}' done.", getContext().getIdentity().getWorkspaceId());
-    return readyIngresses;
-  }
-
   /**
    * When origin exception is not instance of infrastructure exception then it would be wrapped and
    * rethrown.
