@@ -51,7 +51,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Stream;
 import org.eclipse.che.api.core.ValidationException;
 import org.eclipse.che.api.core.model.workspace.config.MachineConfig;
 import org.eclipse.che.api.core.model.workspace.config.ServerConfig;
@@ -87,7 +86,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
 
   public static final String REFERENCE_FILENAME = "reference.yaml";
   public static final String COMPONENT_NAME = "foo";
-  public static final String PROJECT_MOUNT_PATH = "/projects";
 
   private WorkspaceConfigImpl workspaceConfig;
 
@@ -108,13 +106,7 @@ public class KubernetesComponentToWorkspaceApplierTest {
     k8sBasedComponents.add("openshift"); // so that we can work with the petclinic.yaml
     applier =
         new KubernetesComponentToWorkspaceApplier(
-            k8sRecipeParser,
-            k8sEnvProvisioner,
-            envVars,
-            PROJECT_MOUNT_PATH,
-            "Always",
-            MULTI_HOST_STRATEGY,
-            k8sBasedComponents);
+            k8sRecipeParser, k8sEnvProvisioner, envVars, MULTI_HOST_STRATEGY, k8sBasedComponents);
 
     workspaceConfig = new WorkspaceConfigImpl();
   }
@@ -193,7 +185,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
 
     // then
     KubernetesList list = toK8SList(yamlRecipeContent);
-    replaceImagePullPolicy(list, "Always");
     verify(k8sEnvProvisioner)
         .provision(
             eq(workspaceConfig), eq(KubernetesEnvironment.TYPE), eq(list.getItems()), anyMap());
@@ -212,7 +203,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
     applier.apply(workspaceConfig, component, new URLFileContentProvider(null, null));
 
     KubernetesList list = toK8SList(yamlRecipeContent);
-    replaceImagePullPolicy(list, "Always");
 
     verify(k8sEnvProvisioner)
         .provision(
@@ -487,50 +477,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
     }
   }
 
-  @Test
-  public void shouldBeAbleToOverrideImagePullPolicy() throws Exception {
-    // given
-    applier =
-        new KubernetesComponentToWorkspaceApplier(
-            k8sRecipeParser,
-            k8sEnvProvisioner,
-            envVars,
-            PROJECT_MOUNT_PATH,
-            "Never",
-            MULTI_HOST_STRATEGY,
-            k8sBasedComponents);
-    String yamlRecipeContent = getResource("devfile/petclinic.yaml");
-    when(contentProvider.fetchContent(anyString())).thenReturn(yamlRecipeContent);
-    doReturn(toK8SList(yamlRecipeContent).getItems()).when(k8sRecipeParser).parse(anyString());
-    ComponentImpl component = new ComponentImpl();
-    component.setType(KUBERNETES_COMPONENT_TYPE);
-    component.setReference(REFERENCE_FILENAME);
-    component.setAlias(COMPONENT_NAME);
-
-    // when
-    applier.apply(workspaceConfig, component, contentProvider);
-
-    // then
-    verify(k8sEnvProvisioner).provision(any(), any(), objectsCaptor.capture(), any());
-    List<HasMetadata> list = objectsCaptor.getValue();
-    for (HasMetadata o : list) {
-      if (o instanceof Pod) {
-        Pod p = (Pod) o;
-
-        // ignore pods that don't have containers
-        if (p.getSpec() == null) {
-          continue;
-        }
-        List<Container> containers = new ArrayList<>();
-        containers.addAll(p.getSpec().getContainers());
-        containers.addAll(p.getSpec().getInitContainers());
-        for (Container con : containers) {
-          assertEquals(con.getImagePullPolicy(), "Never");
-        }
-      }
-    }
-  }
-
   @Test
   public void shouldProvisionEndpointsToAllMachines()
       throws IOException, ValidationException, InfrastructureException, DevfileException {
@@ -642,7 +588,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
             k8sRecipeParser,
             k8sEnvProvisioner,
             envVars,
-            PROJECT_MOUNT_PATH,
             "Always",
             SINGLE_HOST_STRATEGY,
             k8sBasedComponents);
@@ -692,7 +637,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
             k8sRecipeParser,
             k8sEnvProvisioner,
             envVars,
-            PROJECT_MOUNT_PATH,
             "Always",
             MULTI_HOST_STRATEGY,
             k8sBasedComponents);
@@ -738,19 +682,6 @@ public class KubernetesComponentToWorkspaceApplierTest {
     return unmarshal(content, KubernetesList.class);
   }
 
-  private void replaceImagePullPolicy(KubernetesList list, String imagePullPolicy) {
-    list.getItems().stream()
-        .filter(item -> item instanceof Pod)
-        .map(item -> (Pod) item)
-        .filter(pod -> pod.getSpec() != null)
-        .flatMap(
-            pod ->
-                Stream.concat(
-                    pod.getSpec().getContainers().stream(),
-                    pod.getSpec().getInitContainers().stream()))
-        .forEach(c -> c.setImagePullPolicy(imagePullPolicy));
-  }
-
   private String getResource(String resourceName) throws IOException {
     return Files.readFile(getClass().getClassLoader().getResourceAsStream(resourceName));
   }
