@@ -11,6 +11,7 @@
  */
 package org.eclipse.che.api.factory.server.github;
 
+import static com.google.common.base.MoreObjects.firstNonNull;
 import static com.google.common.base.Strings.isNullOrEmpty;
 import static java.lang.String.format;
 import static java.util.regex.Pattern.compile;
@@ -19,6 +20,7 @@ import static org.eclipse.che.api.factory.server.github.GithubApiClient.GITHUB_S
 import static org.eclipse.che.commons.lang.StringUtils.trimEnd;
 
 import jakarta.validation.constraints.NotNull;
+import java.net.URISyntaxException;
 import java.util.Optional;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -89,14 +91,16 @@ public class GithubURLParser {
     this.devfileFilenamesProvider = devfileFilenamesProvider;
     this.apiClient = githubApiClient;
     this.oauthEndpoint = oauthEndpoint;
+    this.disableSubdomainIsolation = disableSubdomainIsolation;
+
     String endpoint =
         isNullOrEmpty(oauthEndpoint) ? GITHUB_SAAS_ENDPOINT : trimEnd(oauthEndpoint, '/');
+
     this.githubPattern =
         compile(
             format(
                 "^%s/(?<repoUser>[^/]++)/(?<repoName>[^/]++)((/)|(?:/tree/(?<branchName>[^/]++)(?:/(?<subFolder>.*))?)|(/pull/(?<pullRequestId>[^/]++)))?$",
                 endpoint));
-    this.disableSubdomainIsolation = disableSubdomainIsolation;
   }
 
   public boolean isValid(@NotNull String url) {
@@ -130,57 +134,140 @@ public class GithubURLParser {
     if (repoName.matches("^[\\w-][\\w.-]*?\\.git$")) {
       repoName = repoName.substring(0, repoName.length() - 4);
     }
+
     String branchName = matcher.group("branchName");
 
     String pullRequestId = matcher.group("pullRequestId");
+
     if (pullRequestId != null) {
-      try {
-        String githubEndpoint =
-            isNullOrEmpty(oauthEndpoint) ? GITHUB_SAAS_ENDPOINT : trimEnd(oauthEndpoint, '/');
-        Subject subject = EnvironmentContext.getCurrent().getSubject();
-        PersonalAccessToken personalAccessToken = null;
-        Optional<PersonalAccessToken> tokenOptional = tokenManager.get(subject, githubEndpoint);
-        if (tokenOptional.isPresent()) {
-          personalAccessToken = tokenOptional.get();
-        } else if (authenticationRequired) {
-          personalAccessToken = tokenManager.fetchAndSave(subject, githubEndpoint);
+      GithubPullRequest pullRequest =
+          this.getPullRequest(pullRequestId, repoUser, repoName, authenticationRequired);
+      if (pullRequest != null) {
+        String state = pullRequest.getState();
+        if (!"open".equalsIgnoreCase(state)) {
+          throw new IllegalArgumentException(
+              format(
+                  "The given Pull Request url %s is not Opened, (found %s), thus it can't be opened as branch may have been removed.",
+                  url, state));
         }
-        if (personalAccessToken != null) {
-          GithubPullRequest pullRequest =
-              this.apiClient.getPullRequest(
-                  pullRequestId, repoUser, repoName, personalAccessToken.getToken());
-          String prState = pullRequest.getState();
-          if (!"open".equalsIgnoreCase(prState)) {
-            throw new IllegalArgumentException(
-                format(
-                    "The given Pull Request url %s is not Opened, (found %s), thus it can't be opened as branch may have been removed.",
-                    url, prState));
-          }
-          GithubHead pullRequestHead = pullRequest.getHead();
-          repoUser = pullRequestHead.getUser().getLogin();
-          repoName = pullRequestHead.getRepo().getName();
-          branchName = pullRequestHead.getRef();
-        }
-      } catch (ScmUnauthorizedException e) {
-        throw toApiException(e);
-      } catch (ScmCommunicationException
-          | UnsatisfiedScmPreconditionException
-          | ScmConfigurationPersistenceException e) {
-        LOG.error("Failed to authenticate to GitHub", e);
-      } catch (ScmItemNotFoundException | ScmBadRequestException e) {
-        LOG.error("Failed retrieve GitHub Pull Request", e);
-      } catch (UnknownScmProviderException e) {
-        LOG.warn(e.getMessage());
+
+        GithubHead pullRequestHead = pullRequest.getHead();
+        repoUser = pullRequestHead.getUser().getLogin();
+        repoName = pullRequestHead.getRepo().getName();
+        branchName = pullRequestHead.getRef();
       }
     }
 
+    String latestCommit = null;
+    GithubCommit commit =
+        this.getLatestCommit(
+            repoUser, repoName, firstNonNull(branchName, "HEAD"), authenticationRequired);
+    if (commit != null) {
+      latestCommit = commit.getSha();
+    }
+
     return new GithubUrl()
         .withUsername(repoUser)
         .withRepository(repoName)
         .withServerUrl(serverUrl)
         .withDisableSubdomainIsolation(disableSubdomainIsolation)
         .withBranch(branchName)
+        .withLatestCommit(latestCommit)
         .withSubfolder(matcher.group("subFolder"))
         .withDevfileFilenames(devfileFilenamesProvider.getConfiguredDevfileFilenames());
   }
+
+  private GithubPullRequest getPullRequest(
+      String pullRequestId, String repoUser, String repoName, boolean authenticationRequired)
+      throws ApiException {
+    try {
+      // prepare token
+      String githubEndpoint =
+          isNullOrEmpty(oauthEndpoint) ? GITHUB_SAAS_ENDPOINT : trimEnd(oauthEndpoint, '/');
+      Subject subject = EnvironmentContext.getCurrent().getSubject();
+      PersonalAccessToken personalAccessToken = null;
+      Optional<PersonalAccessToken> token = tokenManager.get(subject, githubEndpoint);
+      if (token.isPresent()) {
+        personalAccessToken = token.get();
+      } else if (authenticationRequired) {
+        personalAccessToken = tokenManager.fetchAndSave(subject, githubEndpoint);
+      }
+
+      // get pull request
+      return this.apiClient.getPullRequest(
+          pullRequestId,
+          repoUser,
+          repoName,
+          personalAccessToken != null ? personalAccessToken.getToken() : null);
+    } catch (UnknownScmProviderException e) {
+
+      // get pull request without authentication
+      try {
+        return this.apiClient.getPullRequest(pullRequestId, repoUser, repoName, null);
+      } catch (ScmItemNotFoundException
+          | ScmCommunicationException
+          | ScmBadRequestException exception) {
+        LOG.error("Failed to authenticate to GitHub", e);
+      }
+
+    } catch (ScmUnauthorizedException e) {
+      throw toApiException(e);
+    } catch (ScmCommunicationException
+        | UnsatisfiedScmPreconditionException
+        | ScmConfigurationPersistenceException e) {
+      LOG.error("Failed to authenticate to GitHub", e);
+    } catch (ScmItemNotFoundException | ScmBadRequestException e) {
+      LOG.error("Failed retrieve GitHub Pull Request", e);
+    }
+
+    return null;
+  }
+
+  private GithubCommit getLatestCommit(
+      String repoUser, String repoName, String branchName, boolean authenticationRequired)
+      throws ApiException {
+    try {
+      // prepare token
+      String githubEndpoint =
+          isNullOrEmpty(oauthEndpoint) ? GITHUB_SAAS_ENDPOINT : trimEnd(oauthEndpoint, '/');
+      Subject subject = EnvironmentContext.getCurrent().getSubject();
+      PersonalAccessToken personalAccessToken = null;
+      Optional<PersonalAccessToken> token = tokenManager.get(subject, githubEndpoint);
+      if (token.isPresent()) {
+        personalAccessToken = token.get();
+      } else if (authenticationRequired) {
+        personalAccessToken = tokenManager.fetchAndSave(subject, githubEndpoint);
+      }
+
+      // get latest commit
+      return this.apiClient.getLatestCommit(
+          repoUser,
+          repoName,
+          branchName,
+          personalAccessToken != null ? personalAccessToken.getToken() : null);
+    } catch (UnknownScmProviderException e) {
+
+      // get latest commit without authentication
+      try {
+        return this.apiClient.getLatestCommit(repoUser, repoName, branchName, null);
+      } catch (ScmItemNotFoundException
+          | ScmCommunicationException
+          | ScmBadRequestException
+          | URISyntaxException exception) {
+        LOG.error("Failed to authenticate to GitHub", e);
+      }
+
+    } catch (ScmUnauthorizedException e) {
+      throw toApiException(e);
+    } catch (ScmCommunicationException
+        | UnsatisfiedScmPreconditionException
+        | ScmConfigurationPersistenceException e) {
+      LOG.error("Failed to authenticate to GitHub", e);
+    } catch (ScmItemNotFoundException | ScmBadRequestException | URISyntaxException e) {
+      LOG.error("Failed to retrieve the latest commit", e);
+      e.printStackTrace();
+    }
+
+    return null;
+  }
 }
