@@ -18,6 +18,7 @@ import static com.github.tomakehurst.wiremock.client.WireMock.stubFor;
 import static com.github.tomakehurst.wiremock.client.WireMock.urlEqualTo;
 import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.wireMockConfig;
 import static java.net.HttpURLConnection.HTTP_FORBIDDEN;
+import static org.eclipse.che.api.factory.server.github.GithubPersonalAccessTokenFetcher.DEFAULT_TOKEN_SCOPES;
 import static org.eclipse.che.api.factory.server.scm.PersonalAccessTokenFetcher.OAUTH_2_PREFIX;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
 import static org.mockito.ArgumentMatchers.anyString;
@@ -135,14 +136,14 @@ public class GithubPersonalAccessTokenFetcherTest {
   @Test(
       expectedExceptions = ScmCommunicationException.class,
       expectedExceptionsMessageRegExp =
-          "Current token doesn't have the necessary privileges. Please make sure Che app scopes are correct and containing at least: \\[repo\\]")
+          "Current token doesn't have the necessary privileges. Please make sure Che app scopes are correct and containing at least: \\[repo, user:email, read:user, workflow]")
   public void shouldThrowExceptionOnInsufficientTokenScopes() throws Exception {
     Subject subject = new SubjectImpl("Username", "id1", "token", false);
     OAuthToken oAuthToken = newDto(OAuthToken.class).withToken(githubOauthToken).withScope("");
     when(oAuthAPI.getToken(anyString())).thenReturn(oAuthToken);
 
     stubFor(
-        get(urlEqualTo("/user"))
+        get(urlEqualTo("/api/v3/user"))
             .withHeader(HttpHeaders.AUTHORIZATION, equalTo("token " + githubOauthToken))
             .willReturn(
                 aResponse()
@@ -150,7 +151,7 @@ public class GithubPersonalAccessTokenFetcherTest {
                     .withHeader(GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER, "")
                     .withBodyFile("github/rest/user/response.json")));
 
-    githubPATFetcher.fetchPersonalAccessToken(subject, GithubApiClient.GITHUB_SERVER);
+    githubPATFetcher.fetchPersonalAccessToken(subject, wireMockServer.url("/"));
   }
 
   @Test(
@@ -160,43 +161,47 @@ public class GithubPersonalAccessTokenFetcherTest {
     Subject subject = new SubjectImpl("Username", "id1", "token", false);
     when(oAuthAPI.getToken(anyString())).thenThrow(UnauthorizedException.class);
 
-    githubPATFetcher.fetchPersonalAccessToken(subject, GithubApiClient.GITHUB_SERVER);
+    githubPATFetcher.fetchPersonalAccessToken(subject, wireMockServer.url("/"));
   }
 
   @Test
   public void shouldReturnToken() throws Exception {
     Subject subject = new SubjectImpl("Username", "id1", "token", false);
-    OAuthToken oAuthToken = newDto(OAuthToken.class).withToken(githubOauthToken).withScope("repo");
+    OAuthToken oAuthToken = newDto(OAuthToken.class).withToken(githubOauthToken);
     when(oAuthAPI.getToken(anyString())).thenReturn(oAuthToken);
 
     stubFor(
-        get(urlEqualTo("/user"))
+        get(urlEqualTo("/api/v3/user"))
             .withHeader(HttpHeaders.AUTHORIZATION, equalTo("token " + githubOauthToken))
             .willReturn(
                 aResponse()
                     .withHeader("Content-Type", "application/json; charset=utf-8")
-                    .withHeader(GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER, "repo")
+                    .withHeader(
+                        GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER,
+                        DEFAULT_TOKEN_SCOPES.toString().replace("[", "").replace("]", ""))
                     .withBodyFile("github/rest/user/response.json")));
 
     PersonalAccessToken token =
-        githubPATFetcher.fetchPersonalAccessToken(subject, GithubApiClient.GITHUB_SERVER);
+        githubPATFetcher.fetchPersonalAccessToken(subject, wireMockServer.url("/"));
     assertNotNull(token);
   }
 
   @Test
   public void shouldValidatePersonalToken() throws Exception {
     stubFor(
-        get(urlEqualTo("/user"))
+        get(urlEqualTo("/api/v3/user"))
             .withHeader(HttpHeaders.AUTHORIZATION, equalTo("token " + githubOauthToken))
             .willReturn(
                 aResponse()
                     .withHeader("Content-Type", "application/json; charset=utf-8")
-                    .withHeader(GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER, "repo")
+                    .withHeader(
+                        GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER,
+                        DEFAULT_TOKEN_SCOPES.toString().replace("[", "").replace("]", ""))
                     .withBodyFile("github/rest/user/response.json")));
 
     PersonalAccessToken token =
         new PersonalAccessToken(
-            "https://github.com",
+            wireMockServer.url("/"),
             "cheUser",
             "username",
             "123456789",
@@ -210,17 +215,19 @@ public class GithubPersonalAccessTokenFetcherTest {
   @Test
   public void shouldValidateOauthToken() throws Exception {
     stubFor(
-        get(urlEqualTo("/user"))
+        get(urlEqualTo("/api/v3/user"))
             .withHeader(HttpHeaders.AUTHORIZATION, equalTo("token " + githubOauthToken))
             .willReturn(
                 aResponse()
                     .withHeader("Content-Type", "application/json; charset=utf-8")
-                    .withHeader(GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER, "repo")
+                    .withHeader(
+                        GithubApiClient.GITHUB_OAUTH_SCOPES_HEADER,
+                        DEFAULT_TOKEN_SCOPES.toString().replace("[", "").replace("]", ""))
                     .withBodyFile("github/rest/user/response.json")));
 
     PersonalAccessToken token =
         new PersonalAccessToken(
-            "https://github.com",
+            wireMockServer.url("/"),
             "cheUser",
             "username",
             "123456789",
@@ -233,11 +240,11 @@ public class GithubPersonalAccessTokenFetcherTest {
 
   @Test
   public void shouldNotValidateExpiredOauthToken() throws Exception {
-    stubFor(get(urlEqualTo("/user")).willReturn(aResponse().withStatus(HTTP_FORBIDDEN)));
+    stubFor(get(urlEqualTo("/api/v3/user")).willReturn(aResponse().withStatus(HTTP_FORBIDDEN)));
 
     PersonalAccessToken token =
         new PersonalAccessToken(
-            "https://github.com",
+            wireMockServer.url("/"),
             "cheUser",
             "username",
             "123456789",
